==> snortsms-0.14.9.tbz: www/snortsms/snortctrl/act_Save-Update.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

$temp_id = $_REQUEST['FRM_id'];
$temp_snortargs = mysql_escape_string($_REQUEST['FRM_args']);
$temp_title = $_REQUEST['FRM_title'];
$temp_action = $_REQUEST['BTN_submit'];
$temp_path = $_REQUEST['FRM_path'];
$temp_int = $_REQUEST['FRM_int'];


// DEBUG
//print "<pre>";
//print_r($_REQUEST);
//print "</pre>\n";

if ($temp_action == "Save")	
	{	
	/*** Insert ***/
	$sql = 	"INSERT INTO TBL_SNORT_CTRL ".			"(title,conf_path,interface,snort_args) ".
	"VALUES('$temp_title', '$temp_path', '$temp_int', '$temp_args')";	
	$result = $db->query($sql); if (DB::isError($result)) { Stop ($result->getdebugInfo());}
	}
else
	{
	/*** Update ***/
	$sql =	"UPDATE	TBL_SNORT_CTRL ".	
	"SET ".
	"title = '".$temp_title."', ".
	"conf_path = '".$temp_path."', ".
	"interface = '".$temp_int."', ".
	"snort_args = '".$temp_args."' ".	
	"WHERE id = ".$temp_id;
	$result = $db->query($sql); if (DB::isError($result)) { Stop ($result->getdebugInfo());}
	}
	
header("location:index.php?fuseaction=snortctrl.main");
?>

==> snortsms-1.0.0.tbz: www/snortsms/snortctrl/act_Save-Update.php <==
<?
/***************************************************************************
 *   Copyright (C) 2005 by J Randolph Smith                                *
 *   snortsms@servangle.net                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

$temp_id = $_REQUEST['FRM_id'];
$temp_snortargs = mysql_escape_string($_REQUEST['FRM_args']);
$temp_title = $_REQUEST['FRM_title'];
$temp_action = $_REQUEST['BTN_submit'];
$temp_path = $_REQUEST['FRM_path'];
$temp_int = $_REQUEST['FRM_int'];


// DEBUG
//print "<pre>";
//print_r($_REQUEST);
//print "</pre>\n";

if ($temp_action == "Save")	
	{	
	/*** Insert ***/
	$sql = 	"INSERT INTO TBL_SNORT_CTRL ".			"(title,conf_path,interface,snort_args) ".
	"VALUES('$temp_title', '$temp_path', '$temp_int', '$temp_args')";	
	$result = $db->query($sql); if (DB::isError($result)) { Stop ($result->getdebugInfo());}
	}
else
	{
	/*** Update ***/
	$sql =	"UPDATE	TBL_SNORT_CTRL ".	
	"SET ".
	"title = '".$temp_title."', ".
	"conf_path = '".$temp_path."', ".
	"interface = '".$temp_int."', ".
	"snort_args = '".$temp_snortargs."' ".	
	"WHERE id = ".$temp_id;
	$result = $db->query($sql); if (DB::isError($result)) { Stop ($result->getdebugInfo());}
	}
	
header("location:index.php?fuseaction=snortctrl.main");
?>
